@@ -12,11 +12,12 @@ from .exceptions import (
 )
 
 
-__version__ = "18.1.0"
+__version__ = "21.1.0"
 
-__title__ = "service_identity"
+__title__ = "service-identity"
 __description__ = "Service identity verification for pyOpenSSL & cryptography."
-__uri__ = "https://service-identity.readthedocs.io/"
+__url__ = "https://service-identity.readthedocs.io/"
+__uri__ = __url__
 
 __author__ = "Hynek Schlawack"
 __email__ = "hs@ox.cx"
